@@ -1,9 +1,10 @@
-# -*- coding: utf-8 -*-
-"""This module provides a layer on top of the standard library's
-C{optparse} module, so that we can easily generate both interactive
-help and asciidoc documentation (such as man pages)."""
+"""Command line argument parsing for StGit subcommands.
 
-from __future__ import absolute_import, division, print_function, unicode_literals
+This module provides a layer on top of the standard library's :mod:`optparse` to
+facilitate generation of both interactive help and asciidoc documentation (such as man
+pages).
+
+"""
 
 import io
 import optparse
@@ -17,8 +18,7 @@ from stgit.out import out
 
 
 def _splitlist(lst, split_on):
-    """Iterate over the sublists of lst that are separated by an element e
-    such that split_on(e) is true."""
+    """Split list using provided predicate."""
     current = []
     for e in lst:
         if split_on(e):
@@ -30,13 +30,12 @@ def _splitlist(lst, split_on):
 
 
 def _paragraphs(s):
-    """Split a string s into a list of paragraphs, each of which is a list
-    of lines."""
+    """Split a string s into a list of paragraphs, each of which is a list of lines."""
     lines = [line.rstrip() for line in textwrap.dedent(s).strip().splitlines()]
     return [p for p in _splitlist(lines, lambda line: not line.strip()) if p]
 
 
-class opt(object):
+class opt:
     """Represents a command-line flag."""
 
     def __init__(self, *pargs, **kwargs):
@@ -303,8 +302,12 @@ def diff_opts_option():
 
 
 def author_options():
-    """Sets options.author to a function that modifies a Person
-    according to the commandline options."""
+    """Create command line options for setting author information.
+
+    The ``opts.author`` destination variable is a callback function that modifies a
+    :class:`Person` according to the these command line options.
+
+    """
 
     def short_callback(option, opt_str, value, parser, field):
         f = parser.values.author
@@ -373,9 +376,9 @@ def merged_option():
 
 class strings(list):
     def __init__(self, *args):
-        super(strings, self).__init__(args)
+        super().__init__(args)
 
 
 class patch_range(list):
     def __init__(self, *args):
-        super(patch_range, self).__init__(args)
+        super().__init__(args)
