@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import time
 
 from stgit.argparse import opt
@@ -14,7 +11,6 @@ from stgit.commands.common import (
 )
 from stgit.config import config
 from stgit.exception import StackException
-from stgit.lib import log
 from stgit.lib.git.branch import Branch
 from stgit.lib.git.repository import DetachedHeadException
 from stgit.lib.stack import Stack
@@ -110,7 +106,12 @@ options = [
         of the current branch. The parent information of the new
         branch is copied from the current branch.""",
     ),
-    opt('-r', '--rename', action='store_true', short='Rename an existing branch',),
+    opt(
+        '-r',
+        '--rename',
+        action='store_true',
+        short='Rename an existing branch',
+    ),
     opt(
         '-p',
         '--protect',
@@ -160,7 +161,11 @@ options = [
         A cleaned up branch can be re-initialised using the 'stg init'
         command.""",
     ),
-    opt('-d', '--description', short='Set the branch description'),
+    opt(
+        '-d',
+        '--description',
+        short='Set the branch description',
+    ),
     opt(
         '--merge',
         action='store_true',
@@ -293,6 +298,7 @@ def __create_branch(branch_name, committish):
     stack = Stack.create(
         repository,
         name=branch_name,
+        msg='create %s' % branch_name,
         create_at=branch_commit,
         parent_remote=parentremote,
         parent_branch=parentbranch,
@@ -325,7 +331,6 @@ def func(parser, options, args):
         stack = __create_branch(branch_name, committish)
 
         out.info('Branch "%s" created' % branch_name)
-        log.log_entry(stack, 'branch --create %s' % stack.name)
         return
 
     elif options.clone:
@@ -344,26 +349,13 @@ def func(parser, options, args):
             stack = repository.current_stack
         except StackException:
             stack = None
-            base = repository.refs.get(repository.head_ref)
         else:
             check_head_top_equal(stack)
-            base = stack.base
 
         out.start('Cloning current branch to "%s"' % clone_name)
-        clone = Stack.create(
-            repository,
-            name=clone_name,
-            create_at=base,
-            parent_remote=cur_branch.parent_remote,
-            parent_branch=cur_branch.name,
-        )
+
         if stack:
-            for pn in stack.patchorder.all_visible:
-                patch = stack.patches.get(pn)
-                clone.patches.new(pn, patch.commit, 'clone %s' % stack.name)
-            clone.patchorder.set_order(
-                applied=[], unapplied=stack.patchorder.all_visible, hidden=[]
-            )
+            clone = stack.clone(clone_name, 'branch clone of %s' % cur_branch.name)
             trans = StackTransaction(clone, 'clone')
             try:
                 for pn in stack.patchorder.applied:
@@ -371,15 +363,19 @@ def func(parser, options, args):
             except TransactionHalted:
                 pass
             trans.run()
-        prefix = 'branch.%s.' % cur_branch.name
-        new_prefix = 'branch.%s.' % clone.name
-        for n, v in list(config.getstartswith(prefix)):
-            config.set(n.replace(prefix, new_prefix, 1), v)
+        else:
+            clone = Stack.create(
+                repository,
+                name=clone_name,
+                msg='branch clone of %s' % cur_branch.name,
+                create_at=repository.refs.get(repository.head_ref),
+                parent_remote=cur_branch.parent_remote,
+                parent_branch=cur_branch.name,
+            )
+
         clone.set_description('clone of "%s"' % cur_branch.name)
         clone.switch_to()
         out.done()
-
-        log.copy_log(log.default_repo(), cur_branch.name, clone.name, 'branch --clone')
         return
 
     elif options.delete:
@@ -387,7 +383,6 @@ def func(parser, options, args):
         if len(args) != 1:
             parser.error('incorrect number of arguments')
         __delete_branch(args[0], options.force)
-        log.delete_log(log.default_repo(), args[0])
         return
 
     elif options.cleanup:
@@ -399,7 +394,6 @@ def func(parser, options, args):
         else:
             parser.error('incorrect number of arguments')
         __cleanup_branch(name, options.force)
-        log.delete_log(log.default_repo(), name)
         return
 
     elif options.list:
@@ -457,7 +451,6 @@ def func(parser, options, args):
         stack.rename(new_name)
 
         out.info('Renamed branch "%s" to "%s"' % (old_name, new_name))
-        log.rename_log(repository, old_name, new_name, 'branch --rename')
         return
 
     elif options.unprotect:
