@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt
 from stgit.commands.common import DirectoryHasRepository
 from stgit.lib import transaction
@@ -70,8 +67,7 @@ def _clean(stack, clean_applied, clean_unapplied):
 
 
 def func(parser, options, args):
-    """Delete the empty patches in the series
-    """
+    """Delete the empty patches in the series"""
     if len(args) != 0:
         parser.error('incorrect number of arguments')
 
