@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import os
 
 from stgit.commands.common import (
@@ -49,9 +46,7 @@ directory = DirectoryAnywhere()
 
 
 def func(parser, options, args):
-    """Clone the <repository> into the local <dir> and initialises the
-    stack
-    """
+    """Clone the repository into the local dir and initialise the stack."""
     if len(args) != 2:
         parser.error('incorrect number of arguments')
 
