@@ -113,7 +113,7 @@ def check_local_changes(repository):
 
 
 def check_head_top_equal(stack):
-    if not stack.head_top_equal():
+    if stack.head != stack.top:
         raise CmdException(
             'HEAD and top are not the same. This can happen if you modify a '
             'branch with git. "stg repair --help" explains more about what to '
@@ -136,17 +136,6 @@ def print_current_patch(stack):
         out.info('No patches applied')
 
 
-def get_patch_from_list(part_name, patch_list):
-    candidates = [full for full in patch_list if part_name in full]
-    if len(candidates) >= 2:
-        out.info('Possible patches:\n  %s' % '\n  '.join(candidates))
-        raise CmdException('Ambiguous patch name "%s"' % part_name)
-    elif len(candidates) == 1:
-        return candidates[0]
-    else:
-        return None
-
-
 def parse_patches(patch_args, patch_list, boundary=0, ordered=False):
     """Parse patch_args list for patch names in patch_list.
 
@@ -241,7 +230,7 @@ def address_or_alias(addr_pair):
     raise CmdException('unknown e-mail alias: %s' % addr)
 
 
-def apply_patch(stack, diff, base=None, reject=False, strip=None):
+def apply_patch(stack, diff, base=None, reject=False, strip=None, context_lines=None):
     iw = stack.repository.default_iw
     iw.refresh_index()
     if base:
@@ -250,7 +239,9 @@ def apply_patch(stack, diff, base=None, reject=False, strip=None):
         stack.set_head(base, msg='apply patch')
 
     try:
-        iw.apply(diff, quiet=False, reject=reject, strip=strip)
+        iw.apply(
+            diff, quiet=False, reject=reject, strip=strip, context_lines=context_lines
+        )
     except MergeException:
         if base:
             iw.checkout_hard(orig_head.data.tree)
