@@ -1,6 +1,7 @@
 import os
 import re
 import sys
+import tempfile
 
 from stgit import argparse
 from stgit.argparse import opt
@@ -101,6 +102,13 @@ options = (
             action='store_true',
             short='Strip numbering and extension from patch name',
         ),
+        opt(
+            '-C',
+            dest='context_lines',
+            type='int',
+            metavar='N',
+            short='Ensure N lines of surrounding context for each change',
+        ),
         opt(
             '-i',
             '--ignore',
@@ -202,7 +210,13 @@ def __create_patch(
             tree = stack.head.data.tree
         else:
             iw = stack.repository.default_iw
-            iw.apply(diff, quiet=False, reject=options.reject, strip=options.strip)
+            iw.apply(
+                diff,
+                quiet=False,
+                reject=options.reject,
+                strip=options.strip,
+                context_lines=options.context_lines,
+            )
             tree = iw.index.write_tree()
 
         cd = CommitData(
@@ -328,16 +342,10 @@ def __import_series(filename, options):
 
 def __import_mail(filename, options):
     """Import a patch from an email file or mbox"""
-    import shutil
-    import tempfile
-
-    tmpdir = tempfile.mkdtemp('.stg')
-    try:
+    with tempfile.TemporaryDirectory('.stg') as tmpdir:
         mail_paths = __mailsplit(tmpdir, filename, options)
         for mail_path in mail_paths:
             __import_mail_path(mail_path, filename, options)
-    finally:
-        shutil.rmtree(tmpdir)
 
 
 def __mailsplit(tmpdir, filename, options):
@@ -399,27 +407,24 @@ def __import_mail_path(mail_path, filename, options):
 
 def __import_url(url, options):
     """Import a patch from a URL"""
-    try:
-        from urllib.parse import unquote
-        from urllib.request import urlretrieve
-    except ImportError:
-        from urllib import unquote, urlretrieve
-    import tempfile
+    from urllib.parse import unquote
+    from urllib.request import urlretrieve
 
-    if not url:
-        raise CmdException('URL argument required')
-
-    patch = os.path.basename(unquote(url))
-    filename = os.path.join(tempfile.gettempdir(), patch)
-    urlretrieve(url, filename)
-    __import_file(filename, options)
+    with tempfile.TemporaryDirectory('.stg') as tmpdir:
+        base = os.path.basename(unquote(url))
+        filename = os.path.join(tmpdir, base)
+        urlretrieve(url, filename)
+        if options.series:
+            __import_series(filename, options)
+        elif options.mail or options.mbox:
+            __import_mail(filename, options)
+        else:
+            __import_file(filename, options)
 
 
 def __import_tarfile(tarpath, options):
     """Import patch series from a tar archive"""
-    import shutil
     import tarfile
-    import tempfile
 
     assert tarfile.is_tarfile(tarpath)
 
@@ -441,12 +446,9 @@ def __import_tarfile(tarpath, options):
         raise CmdException("no 'series' file found in %s" % tarpath)
 
     # unpack into a tmp dir
-    tmpdir = tempfile.mkdtemp('.stg')
-    try:
+    with tempfile.TemporaryDirectory('.stg') as tmpdir:
         tar.extractall(tmpdir)
         __import_series(os.path.join(tmpdir, seriesfile), options)
-    finally:
-        shutil.rmtree(tmpdir)
 
 
 def func(parser, options, args):
@@ -454,6 +456,8 @@ def func(parser, options, args):
         parser.error('incorrect number of arguments')
     elif len(args) == 1:
         filename = args[0]
+    elif options.url:
+        raise CmdException('URL argument required')
     else:
         filename = None
 
@@ -469,11 +473,11 @@ def func(parser, options, args):
     check_conflicts(repository.default_iw)
     check_head_top_equal(stack)
 
-    if options.series:
+    if options.url:
+        __import_url(filename, options)
+    elif options.series:
         __import_series(filename, options)
     elif options.mail or options.mbox:
         __import_mail(filename, options)
-    elif options.url:
-        __import_url(filename, options)
     else:
         __import_file(filename, options)
