@@ -112,13 +112,13 @@ def func(parser, options, args):
     pathlim = ['patches/%s' % pn for pn in patches]
 
     if options.graphical:
-        cmd = ['gitk', state.simplified.sha1, '--'] + pathlim
+        cmd = ['gitk', state.simplified_parent.sha1, '--'] + pathlim
         # Discard the exit codes generated by SIGINT, SIGKILL, and SIGTERM.
         stack.repository.run(cmd).returns([0, -2, -9, -15]).run()
     else:
         show_log(
             stack.repository,
-            state.simplified,
+            state.simplified_parent,
             pathlim,
             options.number,
             options.full,
