@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import keep_option, opt, patch_range
 from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
@@ -37,7 +34,12 @@ revert the last push operation)."""
 args = [patch_range('applied_patches')]
 options = (
     [
-        opt('-a', '--all', action='store_true', short='Pop all the applied patches',),
+        opt(
+            '-a',
+            '--all',
+            action='store_true',
+            short='Pop all the applied patches',
+        ),
         opt(
             '-s',
             '--spill',
