@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import keep_option, merged_option, opt, patch_range
 from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
@@ -40,7 +37,10 @@ args = [patch_range('unapplied_patches')]
 options = (
     [
         opt(
-            '-a', '--all', action='store_true', short='Push all the unapplied patches',
+            '-a',
+            '--all',
+            action='store_true',
+            short='Push all the unapplied patches',
         ),
         opt(
             '-n',
@@ -53,7 +53,9 @@ options = (
         With a negative number, push all but that many patches.''',
         ),
         opt(
-            '--reverse', action='store_true', short='Push the patches in reverse order',
+            '--reverse',
+            action='store_true',
+            short='Push the patches in reverse order',
         ),
         opt(
             '--set-tree',
