@@ -105,6 +105,12 @@ options = (
             action='store_true',
             short='Invoke an editor for the patch description',
         ),
+        opt(
+            '-d',
+            '--diff',
+            action='store_true',
+            short='Show diff when editing patch description',
+        ),
         opt(
             '-a',
             '--annotate',
@@ -135,6 +141,7 @@ options = (
         + argparse.hook_options()
         + argparse.sign_options()
         + argparse.author_options()
+        + argparse.diff_opts_option()
     )
 )
 
@@ -145,7 +152,7 @@ def get_patch(stack, given_patch):
     """Get the name of the patch we are to refresh."""
     if given_patch:
         patch_name = given_patch
-        if not stack.patches.exists(patch_name):
+        if patch_name not in stack.patches:
             raise CmdException('%s: no such patch' % patch_name)
         return patch_name
     else:
@@ -161,9 +168,16 @@ def list_files(stack, patch_name, path_limits, update, submodules):
     iw = stack.repository.default_iw
     paths = iw.changed_files(stack.head.data.tree, path_limits or [])
     if update:
-        # --update: Restrict update to the paths that were already
-        # part of the patch.
-        paths &= stack.patches.get(patch_name).files()
+        # --update: Restrict update to the paths that were already part of the patch.
+        patch_paths = set()
+        commit = stack.patches[patch_name]
+        for dt in stack.repository.diff_tree_files(
+            commit.data.parent.data.tree, commit.data.tree
+        ):
+            _, _, _, _, _, oldname, newname = dt
+            patch_paths.add(oldname)
+            patch_paths.add(newname)
+        paths &= patch_paths
     else:
         # Avoid including submodule files by default. This is to ensure that
         # users in repositories with submodueles do not accidentally include
@@ -193,13 +207,12 @@ def write_tree(stack, paths, use_temp_index):
         return index.write_tree()
 
     if use_temp_index:
-        index = stack.repository.temp_index()
-        try:
-            index.read_tree(stack.head)
-            return go(index)
-        finally:
-            index.delete()
-            stack.repository.default_iw.update_index(paths)
+        with stack.repository.temp_index() as index:
+            try:
+                index.read_tree(stack.head)
+                return go(index)
+            finally:
+                stack.repository.default_iw.update_index(paths)
     else:
         return go(stack.repository.default_index)
 
@@ -343,7 +356,7 @@ def __refresh_spill(annotate):
     # Fetch the topmost patch.
     patchname = get_patch(stack, None)
 
-    cd = stack.patches.get(patchname).commit.data
+    cd = stack.patches[patchname].data
 
     # Set the tree of the patch to the parent.
     cd = cd.set_tree(cd.parent.data.tree)
@@ -380,6 +393,8 @@ def __refresh(
     include_submodules=False,
     no_verify=False,
     invoke_editor=False,
+    edit_diff=False,
+    diff_flags=(),
 ):
     stack = directory.repository.current_stack
 
@@ -455,7 +470,7 @@ def __refresh(
         )
         if invoke_editor:
             cd, failed_diff = interactive_edit_patch(
-                stack.repository, cd, edit_diff=False, diff_flags=[]
+                stack.repository, cd, edit_diff, diff_flags
             )
             assert not failed_diff
         if not no_verify and (invoke_editor or cd.message != orig_msg):
@@ -522,4 +537,6 @@ def func(parser, options, args):
             include_submodules=options.submodules,
             no_verify=options.no_verify,
             invoke_editor=options.edit,
+            edit_diff=options.diff,
+            diff_flags=options.diff_flags,
         )
