@@ -1,5 +1,7 @@
 import os
+import time
 
+from stgit.compat import environ_get
 from stgit.exception import StgException
 from stgit.run import Run, RunException
 from stgit.utils import add_dict
@@ -26,20 +28,21 @@ class CheckoutException(StgException):
 class Index:
     """Represents a Git index file."""
 
-    def __init__(self, repository, filename):
+    def __init__(self, repository, index_path):
         self._repository = repository
-        if os.path.isdir(filename):
-            # Create a temp index in the given directory.
-            self._filename = os.path.join(
-                filename, 'index.temp-%d-%x' % (os.getpid(), id(self))
-            )
-            self.delete()
-        else:
-            self._filename = filename
+        self._path = index_path
+
+    @classmethod
+    def default(cls, repository):
+        index_path = environ_get(
+            'GIT_INDEX_FILE',
+            os.path.join(repository.directory, 'index'),
+        )
+        return cls(repository, index_path)
 
     @property
     def env(self):
-        return add_dict(self._repository.env, {'GIT_INDEX_FILE': self._filename})
+        return add_dict(self._repository.env, {'GIT_INDEX_FILE': self._path})
 
     def run(self, args, env=()):
         return Run(*args).env(add_dict(self.env, env))
@@ -134,8 +137,8 @@ class Index:
             return (None, ours)
 
     def delete(self):
-        if os.path.isfile(self._filename):
-            os.remove(self._filename)
+        if os.path.isfile(self._path):
+            os.remove(self._path)
 
     def conflicts(self):
         """The set of conflicting paths."""
@@ -148,18 +151,37 @@ class Index:
         return paths
 
 
+class TemporaryIndex(Index):
+    def __init__(self, repository):
+        index_filename = 'index.temp-%d-%x' % (os.getpid(), int(time.monotonic() * 1e9))
+        index_path = os.path.join(repository.directory, index_filename)
+        if os.path.isfile(index_path):
+            os.remove(index_path)
+        super().__init__(repository, index_path)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.delete()
+        return None
+
+
 class Worktree:
     """Represents a git worktree (that is, a checked-out file tree)."""
 
     def __init__(self, directory):
         self.directory = directory
 
-    @property
-    def env(self):
-        return {'GIT_WORK_TREE': '.'}
+    @classmethod
+    def default(cls):
+        path = environ_get('GIT_WORK_TREE', None)
+        if not path:
+            path = Run('git', 'rev-parse', '--show-toplevel').output_one_line()
+        return cls(path)
 
     @property
-    def env_in_cwd(self):
+    def env(self):
         return {'GIT_WORK_TREE': self.directory}
 
 
@@ -180,19 +202,11 @@ class IndexAndWorktree:
     def env(self):
         return add_dict(self.index.env, self._worktree.env)
 
-    @property
-    def env_in_cwd(self):
-        return self._worktree.env_in_cwd
-
-    @property
-    def cwd(self):
-        return self._worktree.directory
-
     def run(self, args, env=()):
-        return Run(*args).env(add_dict(self.env, env)).cwd(self.cwd)
+        return Run(*args).env(add_dict(self.env, env)).cwd(self._worktree.directory)
 
     def run_in_cwd(self, args):
-        return Run(*args).env(add_dict(self.env, self.env_in_cwd))
+        return Run(*args).env(self.env)
 
     def checkout_hard(self, tree):
         assert isinstance(tree, (Commit, Tree))
@@ -243,13 +257,9 @@ class IndexAndWorktree:
         except RunException:
             raise MergeException('Index/worktree dirty')
 
-    def mergetool(self, files=()):
-        """Resolve outstanding conflicts with `git mergetool`.
-
-        The ``files`` argument may be used to limit the merge to a subset of files.
-
-        """
-        self.run(['git', 'mergetool'] + list(files)).returns([0, 1]).run()
+    def mergetool(self):
+        """Resolve outstanding conflicts with `git mergetool`."""
+        self.run(['git', 'mergetool']).returns([0, 1]).run()
         # check for unmerged entries (prepend 'CONFLICT ' for consistency with merge())
         conflicts = ['CONFLICT ' + f for f in self.index.conflicts()]
         if conflicts:
@@ -292,13 +302,15 @@ class IndexAndWorktree:
         cmd.extend(pathlimits)
         return self.run(cmd).decoding(None).raw_output()
 
-    def apply(self, patch_bytes, quiet, reject=False, strip=None):
+    def apply(self, patch_bytes, quiet, reject=False, strip=None, context_lines=None):
         """Apply patch to worktree."""
         cmd = ['git', 'apply', '--index']
         if reject:
             cmd.append('--reject')
         if strip is not None:
             cmd.append('-p%s' % (strip,))
+        if context_lines is not None:
+            cmd.append('-C%s' % (context_lines,))
         try:
             r = self.run(cmd).encoding(None).raw_input(patch_bytes)
             if quiet:
