@@ -5,13 +5,12 @@ import re
 import signal
 
 from stgit import utils
-from stgit.compat import environ_get
 from stgit.exception import StgException
 from stgit.lib.objcache import ObjectCache
 from stgit.run import Run, RunException
 from stgit.utils import add_dict
 
-from .iw import Index, IndexAndWorktree, MergeException, Worktree
+from .iw import Index, IndexAndWorktree, MergeException, TemporaryIndex, Worktree
 from .objects import Blob, Commit, Tree
 
 
@@ -227,8 +226,12 @@ class DiffTreeProcesses:
         os.write(p.stdin.fileno(), query + end)
         p.stdin.flush()
 
+        def is_end(parts):
+            tail = parts[-1] if len(parts[-1]) > len(end) else b''.join(parts[-2:])
+            return tail.endswith(b'\n' + end) or tail.endswith(b'\0' + end)
+
         parts = [os.read(p.stdout.fileno(), io.DEFAULT_BUFFER_SIZE)]
-        while not (parts[-1].endswith(b'\n' + end) or parts[-1].endswith(b'\0' + end)):
+        while not is_end(parts):
             parts.append(os.read(p.stdout.fileno(), io.DEFAULT_BUFFER_SIZE))
 
         data = b''.join(parts)
@@ -274,30 +277,18 @@ class Repository:
     def default_index(self):
         """An :class:`Index` representing the default index file for the repository."""
         if self._default_index is None:
-            self._default_index = Index(
-                self,
-                (
-                    environ_get('GIT_INDEX_FILE', None)
-                    or os.path.join(self._git_dir, 'index')
-                ),
-            )
+            self._default_index = Index.default(self)
         return self._default_index
 
     def temp_index(self):
         """Return an :class:`Index` representing a new temporary index file."""
-        return Index(self, self._git_dir)
+        return TemporaryIndex(self)
 
     @property
     def default_worktree(self):
         """A :class:`Worktree` representing the default work tree."""
         if self._default_worktree is None:
-            path = environ_get('GIT_WORK_TREE', None)
-            if not path:
-                o = Run('git', 'rev-parse', '--show-cdup').output_lines()
-                o = o or ['.']
-                assert len(o) == 1
-                path = o[0]
-            self._default_worktree = Worktree(path)
+            self._default_worktree = Worktree.default()
         return self._default_worktree
 
     @property
@@ -377,11 +368,8 @@ class Repository:
         )
 
     def simple_merge(self, base, ours, theirs):
-        index = self.temp_index()
-        try:
+        with self.temp_index() as index:
             result, index_tree = index.merge(base, ours, theirs)
-        finally:
-            index.delete()
         return result
 
     def apply(self, tree, patch_bytes, quiet):
@@ -395,16 +383,13 @@ class Repository:
         assert isinstance(tree, Tree)
         if not patch_bytes:
             return tree
-        index = self.temp_index()
-        try:
+        with self.temp_index() as index:
             index.read_tree(tree)
             try:
                 index.apply(patch_bytes, quiet)
                 return index.write_tree()
             except MergeException:
                 return None
-        finally:
-            index.delete()
 
     def submodules(self, tree):
         """Return list of submodule paths for the given :class:`Tree`."""
