@@ -6,7 +6,6 @@ from stgit.exception import StackException
 from stgit.lib import log, stackupgrade
 from stgit.lib.git import Repository
 from stgit.lib.git.branch import Branch, BranchException
-from stgit.lib.objcache import ObjectCache
 
 
 def _stack_state_ref(stack_name):
@@ -19,59 +18,10 @@ def _patch_ref(stack_name, patch_name):
     return 'refs/patches/%s/%s' % (stack_name, patch_name)
 
 
-def _patches_ref_prefix(stack_name):
+def _patch_ref_prefix(stack_name):
     return _patch_ref(stack_name, '')
 
 
-class Patch:
-    """Represents an StGit patch."""
-
-    def __init__(self, stack, name):
-        self._stack = stack
-        self.name = name
-
-    @property
-    def _ref(self):
-        return _patch_ref(self._stack.name, self.name)
-
-    @property
-    def commit(self):
-        return self._stack.repository.refs.get(self._ref)
-
-    def set_commit(self, commit, msg):
-        try:
-            old_sha1 = self.commit.sha1
-        except KeyError:
-            old_sha1 = None
-        self._stack.repository.refs.set(self._ref, commit, msg)
-        if old_sha1 and old_sha1 != commit.sha1:
-            self._stack.repository.copy_notes(old_sha1, commit.sha1)
-
-    def set_name(self, name, msg):
-        commit = self.commit
-        self.delete()
-        self.name = name
-        self._stack.repository.refs.set(self._ref, commit, msg)
-
-    def delete(self):
-        self._stack.repository.refs.delete(self._ref)
-
-    def is_empty(self):
-        return self.commit.data.is_nochange()
-
-    def files(self):
-        """Return the set of files this patch touches."""
-        fs = set()
-        for dt in self._stack.repository.diff_tree_files(
-            self.commit.data.parent.data.tree,
-            self.commit.data.tree,
-        ):
-            _, _, _, _, _, oldname, newname = dt
-            fs.add(oldname)
-            fs.add(newname)
-        return fs
-
-
 class PatchOrder:
     """Keeps track of patch order, and which patches are applied.
 
@@ -125,31 +75,61 @@ class PatchOrder:
 
 
 class Patches:
-    """Manage the set of :class:`Patch` objects.
-
-    Ensures a single :class:`Patch` instance per patch.
-
-    """
+    """Interface for managing patch references."""
 
     def __init__(self, stack, state):
         self._stack = stack
 
-        def create_patch(name):
-            p = Patch(self._stack, name)
-            p.commit  # raise exception if the patch doesn't exist
-            return p
+        # Ensure patch refs in repository match those from stack state.
+        repository = stack.repository
+        patch_ref_prefix = _patch_ref_prefix(stack.name)
 
-        self._patches = ObjectCache(create_patch)  # name -> Patch
+        state_patch_ref_map = {
+            _patch_ref(stack.name, pn): commit for pn, commit in state.patches.items()
+        }
 
-    def exists(self, name):
-        try:
-            self.get(name)
-            return True
-        except KeyError:
-            return False
+        state_patch_refs = set(state_patch_ref_map)
+        repo_patch_refs = {
+            ref for ref in repository.refs if ref.startswith(patch_ref_prefix)
+        }
 
-    def get(self, name):
-        return self._patches[name]
+        delete_patch_refs = repo_patch_refs - state_patch_refs
+        create_patch_refs = state_patch_refs - repo_patch_refs
+        update_patch_refs = {
+            ref
+            for ref in state_patch_refs - create_patch_refs
+            if state_patch_ref_map[ref].sha1 != repository.refs.get(ref).sha1
+        }
+
+        if create_patch_refs or update_patch_refs or delete_patch_refs:
+            repository.refs.batch_update(
+                msg='restore from stack state',
+                create=[(ref, state_patch_ref_map[ref]) for ref in create_patch_refs],
+                update=[(ref, state_patch_ref_map[ref]) for ref in update_patch_refs],
+                delete=delete_patch_refs,
+            )
+
+    def _patch_ref(self, name):
+        return _patch_ref(self._stack.name, name)
+
+    def __contains__(self, name):
+        return self._stack.repository.refs.exists(self._patch_ref(name))
+
+    def __getitem__(self, name):
+        return self._stack.repository.refs.get(self._patch_ref(name))
+
+    def __iter__(self):
+        patch_ref_prefix = _patch_ref_prefix(self._stack.name)
+        for ref in self._stack.repository.refs:
+            if ref.startswith(patch_ref_prefix):
+                yield ref[len(patch_ref_prefix) :]
+
+    def name_from_sha1(self, partial_sha1):
+        for pn in self:
+            if self[pn].sha1.startswith(partial_sha1.lower()):
+                return pn
+        else:
+            return None
 
     def is_name_valid(self, name):
         if '/' in name:
@@ -161,12 +141,23 @@ class Patches:
         return p.exitcode == 0
 
     def new(self, name, commit, msg):
-        assert name not in self._patches
+        assert name not in self
         assert self.is_name_valid(name)
-        p = Patch(self._stack, name)
-        p.set_commit(commit, msg)
-        self._patches[name] = p
-        return p
+        self._stack.repository.refs.set(self._patch_ref(name), commit, msg)
+
+    def update(self, name, commit, msg):
+        old_sha1 = self[name].sha1
+        if old_sha1 != commit.sha1:
+            self._stack.repository.refs.set(self._patch_ref(name), commit, msg)
+            self._stack.repository.copy_notes(old_sha1, commit.sha1)
+
+    def rename(self, old_name, new_name, msg):
+        commit = self[old_name]
+        self._stack.repository.refs.delete(self._patch_ref(old_name))
+        self._stack.repository.refs.set(self._patch_ref(new_name), commit, msg)
+
+    def delete(self, name):
+        self._stack.repository.refs.delete(self._patch_ref(name))
 
     def make_name(self, raw, unique=True, lower=True, allow=(), disallow=()):
         """Make a unique and valid patch name from provided raw name.
@@ -229,7 +220,7 @@ class Patches:
 
         unique_name = short_name
         while unique_name not in allow and (
-            self.exists(unique_name) or unique_name in disallow
+            unique_name in self or unique_name in disallow
         ):
             m = re.match(r'(.*?)(-)?(\d+)$', unique_name)
             if m:
@@ -258,14 +249,13 @@ class Stack(Branch):
         if not stackupgrade.update_to_current_format_version(repository, name):
             raise StackException('%s: branch not initialized' % name)
         state = log.get_stack_state(self.repository, self.state_ref)
-        self._ensure_patch_refs(repository, name, state)
         self.patchorder = PatchOrder(state)
         self.patches = Patches(self, state)
 
     @property
     def base(self):
         if self.patchorder.applied:
-            return self.patches.get(self.patchorder.applied[0]).commit.data.parent
+            return self.patches[self.patchorder.applied[0]].data.parent
         else:
             return self.head
 
@@ -273,17 +263,11 @@ class Stack(Branch):
     def top(self):
         """Commit of the topmost patch, or the stack base if no patches are applied."""
         if self.patchorder.applied:
-            return self.patches.get(self.patchorder.applied[-1]).commit
+            return self.patches[self.patchorder.applied[-1]]
         else:
             # When no patches are applied, base == head.
             return self.head
 
-    def head_top_equal(self):
-        if not self.patchorder.applied:
-            return True
-        top = self.patches.get(self.patchorder.applied[-1]).commit
-        return self.head == top
-
     def set_parents(self, remote, branch):
         if remote:
             self.set_parent_remote(remote)
@@ -310,15 +294,13 @@ class Stack(Branch):
     def cleanup(self):
         assert not self.protected, 'attempt to delete protected stack'
         for pn in self.patchorder.all:
-            patch = self.patches.get(pn)
-            patch.delete()
+            self.patches.delete(pn)
         self.repository.refs.delete(self.state_ref)
         config.remove_section('branch.%s.stgit' % self.name)
 
     def clear_log(self, msg='clear log'):
-        state_commit = log.StackState.from_stack(
-            prev=None, stack=self, message=msg
-        ).commit_state()
+        stack_state = log.StackState.from_stack(prev=None, stack=self)
+        state_commit = stack_state.commit_state(self.repository, msg)
         self.repository.refs.set(self.state_ref, state_commit, msg=msg)
 
     def rename(self, new_name):
@@ -340,14 +322,14 @@ class Stack(Branch):
     def rename_patch(self, old_name, new_name, msg='rename'):
         if new_name == old_name:
             raise StackException('New patch name same as old: "%s"' % new_name)
-        elif self.patches.exists(new_name):
+        elif new_name in self.patches:
             raise StackException('Patch already exists: "%s"' % new_name)
         elif not self.patches.is_name_valid(new_name):
             raise StackException('Invalid patch name: "%s"' % new_name)
-        elif not self.patches.exists(old_name):
+        elif old_name not in self.patches:
             raise StackException('Unknown patch name: "%s"' % old_name)
         self.patchorder.rename_patch(old_name, new_name)
-        self.patches.get(old_name).set_name(new_name, msg)
+        self.patches.rename(old_name, new_name, msg)
 
     def clone(self, clone_name, msg):
         clone = self.create(
@@ -360,8 +342,7 @@ class Stack(Branch):
         )
 
         for pn in self.patchorder.all_visible:
-            patch = self.patches.get(pn)
-            clone.patches.new(pn, patch.commit, 'clone from %s' % self.name)
+            clone.patches.new(pn, self.patches[pn], 'clone from %s' % self.name)
 
         clone.patchorder.set_order(
             applied=[],
@@ -403,16 +384,8 @@ class Stack(Branch):
         if switch_to:
             branch.switch_to()
 
-        state_commit = log.StackState(
-            repository,
-            prev=None,
-            head=branch.head,
-            applied=[],
-            unapplied=[],
-            hidden=[],
-            patches={},
-            message=msg,
-        ).commit_state()
+        stack_state = log.StackState.new_empty(branch.head)
+        state_commit = stack_state.commit_state(repository, msg)
         repository.refs.set(stack_state_ref, state_commit, msg)
 
         return repository.get_stack(name)
@@ -447,36 +420,6 @@ class Stack(Branch):
         stack.set_parents(parent_remote, parent_branch)
         return stack
 
-    @staticmethod
-    def _ensure_patch_refs(repository, stack_name, state):
-        """Ensure patch refs in repository match those from stack state."""
-        patch_ref_prefix = _patches_ref_prefix(stack_name)
-
-        state_patch_ref_map = {
-            _patch_ref(stack_name, pn): commit for pn, commit in state.patches.items()
-        }
-
-        state_patch_refs = set(state_patch_ref_map)
-        repo_patch_refs = {
-            ref for ref in repository.refs if ref.startswith(patch_ref_prefix)
-        }
-
-        delete_patch_refs = repo_patch_refs - state_patch_refs
-        create_patch_refs = state_patch_refs - repo_patch_refs
-        update_patch_refs = {
-            ref
-            for ref in state_patch_refs - create_patch_refs
-            if state_patch_ref_map[ref].sha1 != repository.refs.get(ref).sha1
-        }
-
-        if create_patch_refs or update_patch_refs or delete_patch_refs:
-            repository.refs.batch_update(
-                msg='restore from stack state',
-                create=[(ref, state_patch_ref_map[ref]) for ref in create_patch_refs],
-                update=[(ref, state_patch_ref_map[ref]) for ref in update_patch_refs],
-                delete=delete_patch_refs,
-            )
-
 
 class StackRepository(Repository):
     """A Git :class:`Repository` with some added StGit-specific operations."""
