@@ -52,7 +52,7 @@ class _TransPatchMap(dict):
         try:
             return super().__getitem__(pn)
         except KeyError:
-            return self._stack.patches.get(pn).commit
+            return self._stack.patches[pn]
 
 
 class StackTransaction:
@@ -188,7 +188,7 @@ class StackTransaction:
         self._bad_head = value
 
     def _assert_head_top_equal(self):
-        if not self.stack.head_top_equal():
+        if self.stack.head != self.stack.top:
             out.error(
                 'HEAD and top are not the same.',
                 'This can happen if you modify a branch with git.',
@@ -229,7 +229,7 @@ class StackTransaction:
         remaining = set(self.all_patches)
         for pn, commit in self.patches.items():
             if commit is None:
-                assert self.stack.patches.exists(pn)
+                assert pn in self.stack.patches
             else:
                 assert pn in remaining
 
@@ -272,12 +272,11 @@ class StackTransaction:
 
         # Write patches.
         for pn, commit in self.patches.items():
-            if self.stack.patches.exists(pn):
-                p = self.stack.patches.get(pn)
+            if pn in self.stack.patches:
                 if commit is None:
-                    p.delete()
+                    self.stack.patches.delete(pn)
                 else:
-                    p.set_commit(commit, msg)
+                    self.stack.patches.update(pn, commit, msg)
             else:
                 self.stack.patches.new(pn, commit, msg)
         self.stack.patchorder.set_order(self._applied, self._unapplied, self._hidden)
