@@ -13,7 +13,9 @@ test_expect_success 'Initialize the StGIT repository' '
 '
 
 test_expect_success 'Empty log' '
-    stg log 2>&1 >/dev/null | grep -e "Log is empty"
+    stg log > log.txt &&
+    test_line_count = 1 log.txt &&
+    head -n 1 log.txt | grep -e "initialise"
 '
 
 test_expect_success 'Add some patches' '
@@ -103,6 +105,18 @@ test_expect_success 'Verify log for p3' '
     head -n 3 log.txt | tail -n 1 | grep -e "uncommit"
 '
 
+test_expect_success 'Verify log with patch limit from subdir' '
+    mkdir subdir &&
+    (cd subdir &&
+     stg log p3 > ../log.txt
+    ) &&
+    rmdir subdir &&
+    test_line_count = 3 log.txt &&
+    head -n 1 log.txt | tail -n 1 | grep -e "edit" &&
+    head -n 2 log.txt | tail -n 1 | grep -e "goto" &&
+    head -n 3 log.txt | tail -n 1 | grep -e "uncommit"
+'
+
 test_expect_success 'Verify log for p2 and p3' '
     stg log p2 p3 > log.txt &&
     test_line_count = 5 log.txt &&
@@ -124,7 +138,9 @@ test_expect_success 'Log with number' '
 test_expect_success 'Clear the log' '
     stg log --clear &&
     test "$(echo $(stg series --noprefix))" = "p0 p1 p2 p3" &&
-    stg log 2>&1 >/dev/null | grep -e "Log is empty"
+    stg log > log.txt &&
+    test_line_count = 1 log.txt &&
+    head -n 1 log.txt | grep -e "clear log"
 '
 
 test_done
