@@ -37,8 +37,23 @@ test_expect_success \
     '
     stg branch --clone bar &&
     test "$(stg series --applied -c)" -eq 1 &&
+    test "$(git config --get branch.bar.description)" = "clone of \"foo\"" &&
     stg new p2 -m "p2" &&
     test "$(stg series --applied -c)" -eq 2
     '
 
+test_expect_success \
+    'Anonymous clone' \
+    '
+    stg branch --clone &&
+    stg branch |
+    grep -E "^bar-[0-9]+-[0-9]+"
+    '
+
+test_expect_success \
+    'Invalid clone args' \
+    '
+    command_error stg branch --clone bname extra
+    '
+
 test_done
