@@ -45,6 +45,38 @@ test_expect_success \
     [ "$(echo $(stg series --unapplied --noprefix))" = "" ]
     '
 
+test_expect_success \
+    'Attempt sync with current branch' \
+    '
+    command_error stg sync -B foo 2>&1 |
+    grep -e "Cannot synchronise with the current branch"
+    '
+
+test_expect_success \
+    'Attempt sync without remote branch or series' \
+    '
+    command_error stg sync -a 2>&1 |
+    grep -e "No remote branch or series specified"
+    '
+
+test_expect_success \
+    'Attempt apply top patch without any applied' \
+    '
+    test_when_finished "stg goto p3" &&
+    stg pop -a &&
+    command_error stg sync -B master 2>&1 |
+    grep -e "no patches applied"
+    '
+
+test_expect_success \
+    'Attempt to sync patch not in ref branch' \
+    '
+    stg new -m p4 &&
+    test_when_finished "stg delete p4" &&
+    command_error stg sync -B master 2>&1 |
+    grep -e "No common patches to be synchronised"
+    '
+
 test_expect_success \
     'Synchronise second patch with the master branch' \
     '
@@ -100,16 +132,17 @@ test_expect_success \
 test_expect_success \
     'Synchronise second patch with the master branch' \
     '
+    stg goto p1 &&
     stg sync -B master p2 &&
-    [ "$(echo $(stg series --applied --noprefix))" = "p1 p2 p3" ] &&
-    [ "$(echo $(stg series --unapplied --noprefix))" = "" ] &&
+    [ "$(echo $(stg series --applied --noprefix))" = "p1 p2" ] &&
+    [ "$(echo $(stg series --unapplied --noprefix))" = "p3" ] &&
     test "$(cat bar2.txt)" = "bar2"
     '
 
 test_expect_success \
     'Synchronise the first two patches with the master branch (to fail)' \
     '
-    conflict_old stg sync -B master -a
+    conflict stg sync -B master -a
     '
 
 test_expect_success \
@@ -127,7 +160,7 @@ test_expect_success \
 test_expect_success \
     'Synchronise the third patch with the exported series (to fail)' \
     '
-    conflict_old stg sync -s patches-master/series p3
+    conflict stg sync -s patches-master/series p3
     '
 
 test_expect_success \
