@@ -40,6 +40,15 @@ test_expect_success 'refresh with path limiting, succeeding hook' '
     stg refresh file
 '
 
+git config core.hooksPath .my-hooks
+mv "$HOOKDIR" .my-hooks
+test_expect_success 'refresh with core.hooksPath' '
+    echo "pre-commit-hook-path-limiting-success" >> file &&
+    stg refresh file
+'
+mv .my-hooks "$HOOKDIR"
+git config --unset core.hooksPath
+
 # now a hook that fails
 write_script "$HOOK" <<'EOF'
 exit 1
@@ -152,4 +161,4 @@ test_expect_success 'refresh with path limiting, failing hook that modifies file
     git diff-index --quiet HEAD
 '
 
-test_done
\ No newline at end of file
+test_done
